You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@mxnet.apache.org by je...@apache.org on 2023/09/01 19:31:06 UTC

[mxnet] branch update_cuda created (now 9abe5a9859)

This is an automated email from the ASF dual-hosted git repository.

jevans pushed a change to branch update_cuda
in repository https://gitbox.apache.org/repos/asf/mxnet.git


      at 9abe5a9859 Update cuda versions and remove deprecated versions.

This branch includes the following new commits:

     new 9abe5a9859 Update cuda versions and remove deprecated versions.

The 1 revisions listed above as "new" are entirely new to this
repository and will be described in separate emails.  The revisions
listed as "add" were already present in the repository and have only
been added to this reference.



[mxnet] 01/01: Update cuda versions and remove deprecated versions.

Posted by je...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

jevans pushed a commit to branch update_cuda
in repository https://gitbox.apache.org/repos/asf/mxnet.git

commit 9abe5a98591775c6973827b9cc5bfb52d6acd3ff
Author: Joe Evans <jo...@gmail.com>
AuthorDate: Fri Sep 1 12:30:49 2023 -0700

    Update cuda versions and remove deprecated versions.
---
 ci/docker/docker-compose.yml    | 44 ++++++++++++++++-------------------------
 ci/docker/runtime_functions.sh  |  6 +++---
 ci/jenkins/Jenkins_steps.groovy | 12 +++++------
 3 files changed, 26 insertions(+), 36 deletions(-)

diff --git a/ci/docker/docker-compose.yml b/ci/docker/docker-compose.yml
index 9e19bb2e09..ced10f9700 100644
--- a/ci/docker/docker-compose.yml
+++ b/ci/docker/docker-compose.yml
@@ -41,26 +41,6 @@ services:
         BASE_IMAGE: centos:7
       cache_from:
         - ${DOCKER_CACHE_REGISTRY}/build.centos7_cpu:latest
-  centos7_gpu_cu101:
-    image: ${DOCKER_CACHE_REGISTRY}/build.centos7_gpu_cu101:latest
-    build:
-      context: .
-      dockerfile: Dockerfile.build.centos7
-      target: base
-      args:
-        BASE_IMAGE: nvidia/cuda:10.1-cudnn8-devel-centos7
-      cache_from:
-        - ${DOCKER_CACHE_REGISTRY}/build.centos7_gpu_cu101:latest
-  centos7_gpu_cu102:
-    image: ${DOCKER_CACHE_REGISTRY}/build.centos7_gpu_cu102:latest
-    build:
-      context: .
-      dockerfile: Dockerfile.build.centos7
-      target: base
-      args:
-        BASE_IMAGE: nvidia/cuda:10.2-cudnn8-devel-centos7
-      cache_from:
-        - ${DOCKER_CACHE_REGISTRY}/build.centos7_gpu_cu102:latest
   centos7_gpu_cu110:
     image: ${DOCKER_CACHE_REGISTRY}/build.centos7_gpu_cu110:latest
     build:
@@ -78,9 +58,19 @@ services:
       dockerfile: Dockerfile.build.centos7
       target: base
       args:
-        BASE_IMAGE: nvidia/cuda:11.2.0-cudnn8-devel-centos7
+        BASE_IMAGE: nvidia/cuda:11.2.2-cudnn8-devel-centos7
       cache_from:
         - ${DOCKER_CACHE_REGISTRY}/build.centos7_gpu_cu112:latest
+  centos7_gpu_cu118:
+    image: ${DOCKER_CACHE_REGISTRY}/build.centos7_gpu_cu118:latest
+    build:
+      context: .
+      dockerfile: Dockerfile.build.centos7
+      target: base
+      args:
+        BASE_IMAGE: nvidia/cuda:11.8.0-cudnn8-devel-centos7
+      cache_from:
+        - ${DOCKER_CACHE_REGISTRY}/build.centos7_gpu_cu118:latest
   ###################################################################################################
   # Dockerfile.build.ubuntu based images. On Ubuntu we test more recent
   # toolchain and dependency versions compared to CentOS7. We attempt to update
@@ -105,20 +95,20 @@ services:
       dockerfile: Dockerfile.build.ubuntu
       target: gpu
       args:
-        BASE_IMAGE: nvidia/cuda:11.4.0-cudnn8-devel-ubuntu20.04
+        BASE_IMAGE: nvidia/cuda:11.4.3-cudnn8-devel-ubuntu20.04
         TRT_VERSION: 8.2.4-1+cuda11.4
       cache_from:
         - ${DOCKER_CACHE_REGISTRY}/build.ubuntu_tensorrt_cu114:latest
-  ubuntu_gpu_cu111:
-    image: ${DOCKER_CACHE_REGISTRY}/build.ubuntu_gpu_cu111:latest
+  ubuntu_gpu_cu118:
+    image: ${DOCKER_CACHE_REGISTRY}/build.ubuntu_gpu_cu118:latest
     build:
       context: .
       dockerfile: Dockerfile.build.ubuntu
       target: gpu
       args:
-        BASE_IMAGE: nvidia/cuda:11.1.1-cudnn8-devel-ubuntu20.04
+        BASE_IMAGE: nvidia/cuda:11.8.0-cudnn8-devel-ubuntu20.04
       cache_from:
-        - ${DOCKER_CACHE_REGISTRY}/build.ubuntu_gpu_cu111:latest
+        - ${DOCKER_CACHE_REGISTRY}/build.ubuntu_gpu_cu118:latest
   ###################################################################################################
   # Dockerfile.build.android based images used for testing cross-compilation for plain ARM
   ###################################################################################################
@@ -204,7 +194,7 @@ services:
       context: .
       dockerfile: Dockerfile.publish.test.centos7
       args:
-        BASE_IMAGE: nvidia/cuda:9.2-cudnn7-devel-centos7
+        BASE_IMAGE: nvidia/cuda:11.8.0-cudnn8-devel-centos7
       cache_from:
         - ${DOCKER_CACHE_REGISTRY}/publish.test.centos7_gpu:latest
   ###################################################################################################
diff --git a/ci/jenkins/Jenkins_steps.groovy b/ci/jenkins/Jenkins_steps.groovy
index 81dfe4e8f3..d70f3815a6 100644
--- a/ci/jenkins/Jenkins_steps.groovy
+++ b/ci/jenkins/Jenkins_steps.groovy
@@ -304,7 +304,7 @@ def compile_centos7_gpu(lib_name) {
         ws('workspace/build-centos7-gpu') {
           timeout(time: max_time, unit: 'MINUTES') {
             utils.init_git()
-            utils.docker_run('centos7_gpu_cu102', 'build_centos7_gpu', false)
+            utils.docker_run('centos7_gpu_cu118', 'build_centos7_gpu', false)
             utils.pack_lib(lib_name, mx_lib)
           }
         }
@@ -633,7 +633,7 @@ def compile_static_python_gpu() {
         ws('workspace/ut-publish-python-gpu') {
           timeout(time: max_time, unit: 'MINUTES') {
             utils.init_git()
-            utils.docker_run('centos7_gpu_cu102', 'build_static_python_cu102')
+            utils.docker_run('centos7_gpu_cu118', 'build_static_python_cu118')
           }
         }
     }
@@ -646,7 +646,7 @@ def compile_static_cd_gpu(lib_name) {
         ws('workspace/build-cd-static/gpu') {
           timeout(time: max_time, unit: 'MINUTES') {
             utils.init_git()
-            utils.docker_run('centos7_gpu_cu102', 'build_static_libmxnet cu102', false)
+            utils.docker_run('centos7_gpu_cu118', 'build_static_libmxnet cu118', false)
             utils.pack_lib(lib_name, mx_cd_lib)
           }
         }
@@ -982,7 +982,7 @@ def test_centos7_python3_gpu(lib_name) {
           timeout(time: max_time, unit: 'MINUTES') {
             try {
               utils.unpack_and_init(lib_name, mx_lib)
-              utils.docker_run('centos7_gpu_cu102', 'unittest_centos7_gpu', true)
+              utils.docker_run('centos7_gpu_cu118', 'unittest_centos7_gpu', true)
               utils.publish_test_coverage()
             } finally {
               utils.collect_test_results_unix('tests_gpu.xml', 'tests_python3_centos7_gpu.xml')
@@ -999,7 +999,7 @@ def test_centos7_python3_cd_gpu(lib_name) {
         ws('workspace/test-cd-static/gpu') {
           timeout(time: max_time, unit: 'MINUTES') {
             utils.unpack_and_init(lib_name, mx_cd_lib)
-            utils.docker_run('centos7_gpu_cu102', 'cd_unittest_ubuntu cu102', true)
+            utils.docker_run('centos7_gpu_cu118', 'cd_unittest_ubuntu cu118', true)
           }
         }
       }
@@ -1012,7 +1012,7 @@ def test_centos7_pypi_package_cd_gpu(lib_name) {
         ws('workspace/test-cd-pypi/gpu') {
           timeout(time: max_time, unit: 'MINUTES') {
             utils.unpack_and_init(lib_name, mx_cd_lib)
-            utils.docker_run('centos7_gpu_cu102', 'ci_package_pypi cu102', true)
+            utils.docker_run('centos7_gpu_cu118', 'ci_package_pypi cu118', true)
           }
         }
       }
diff --git a/ci/docker/runtime_functions.sh b/ci/docker/runtime_functions.sh
index 2a19f36155..1c3e00b7be 100755
--- a/ci/docker/runtime_functions.sh
+++ b/ci/docker/runtime_functions.sh
@@ -111,7 +111,7 @@ gather_licenses() {
 
 # Compiles the dynamic mxnet library
 # Parameters:
 # $1 -> mxnet_variant: the mxnet variant to build, e.g. cpu, native, cu101, cu102, etc.
 build_dynamic_libmxnet() {
     set -ex
 
@@ -1504,10 +1504,10 @@ build_static_python_cpu() {
     popd
 }
 
-build_static_python_cu102() {
+build_static_python_cu118() {
     set -ex
     pushd .
-    export mxnet_variant=cu102
+    export mxnet_variant=cu118
     source /opt/rh/devtoolset-8/enable
     source /opt/rh/rh-python38/enable
     # Opt in to newer GCC C++ ABI. devtoolset defaults to ABI Version 2.
@@ -111,7 +111,7 @@ gather_licenses() {
 # Compiles the dynamic mxnet library
 # Parameters:
-# $1 -> mxnet_variant: the mxnet variant to build, e.g. cpu, native, cu101, cu102, etc.
+# $1 -> mxnet_variant: the mxnet variant to build, e.g. cpu, native, cu112, cu118, etc.
 build_dynamic_libmxnet() {
     set -ex